var bizagiUtil = require('bz-util');
var REQUIRED = bizagiUtil.REQUIRED;
var ERROR = bizagiUtil.error;
var RESPONSE = bizagiUtil.getResponse;
 
/**
 * @author luis.avila@bizagi.com
 */ 

function invoke(globals, actionName, data, authenticationType, LOG, callback) {
    var Web3 = REQUIRED('web3');

    try {
        var web3 = new Web3();
        
        var ip = globals.systemproperties.ip;
        var port = globals.systemproperties.port;    
        web3 = new Web3(new Web3.providers.HttpProvider('http://' + ip + ':' + port));
    
        var number = data.inputs.input.number;
    
        web3.eth.getBlock(number, function(error, result) {
            if (!error && !result) {
                var errorData = {
                    error: 'Not found!',
                    message: 'Not found!',
                    status: 400
                }
                var error = RESPONSE(null, errorData, errorData.status, errorData.error);
                callback(error);
            } else if (!error && result) {
                var messageData = {
                    extraData: result.extraData,
                    gasLimit: result.gasLimit,
                    gasUsed: result.gasUsed,
                    hash: result.hash,
                    miner: result.miner,
                    nonce: result.nonce,
                    parentHash: result.parentHash,
                    receiptRoot: result.receiptRoot,
                    sha3Uncles: result.sha3Uncles,
                    size: result.size,
                    timestamp: result.timestamp,
                    stateRoot: result.stateRoot,
                    number: result.number
                }
                var success = RESPONSE(messageData, null, 200);
                callback(success);
            } else {
                var errorData = {
                    error: error,
                    message: error,
                    status: 400
                }
                var error = RESPONSE(null, errorData, errorData.status, errorData.error);
                callback(error);
            }
        });
    } catch (ex) {
        var errorData = {
            error: 'Error connecting. Verify connection!',
            message: 'Error connecting. Verify connection!',
            status: 400
        }
        var error = RESPONSE(null, errorData, errorData.status, errorData.error);
        callback(error);
    }
}

exports.invoke = invoke;